caffeine_lang/linker/artifacts

Types

Types of dependency relationships between expectations.

pub type DependencyRelationType {
  Hard
  Soft
}

Constructors

  • Hard

    If dependency down, dependent down.

  • Soft

    Dependent can continue operating, either unscathed or within a degraded state if deendency down.

Information about a parameter including its type and description.

pub type ParamInfo {
  ParamInfo(type_: types.AcceptedTypes, description: String)
}

Constructors

Search Document