caffeine_lang/linker/blueprints

Types

A Blueprint that references one or more Artifacts with parameters and inputs. It provides further params for the Expectation to satisfy while providing a partial set of inputs for the Artifact’s params. The phantom type parameter state tracks whether the blueprint is Raw or BlueprintValidated.

pub type Blueprint(state) {
  Blueprint(
    name: String,
    artifact_refs: List(artifacts.ArtifactType),
    params: dict.Dict(String, types.AcceptedTypes),
    inputs: dict.Dict(String, value.Value),
  )
}

Constructors

Marker type for blueprints that have passed validation.

pub type BlueprintValidated

Marker type for blueprints that have not yet been validated.

pub type Raw
Search Document