caffeine_lang/parser/blueprints

Types

A Blueprint that references one or more Artifacts with parameters and inputs. It provides further params for the Expectation to satisfy while providing a partial set of inputs for the Artifact’s params.

pub type Blueprint {
  Blueprint(
    name: String,
    artifact_refs: List(String),
    params: dict.Dict(String, accepted_types.AcceptedTypes),
    inputs: dict.Dict(String, dynamic.Dynamic),
  )
}

Constructors

Search Document