caffeine_lang/phase_1/parser/utils/general_common

Values

pub fn extract_params_from_file_path(
  file_path: String,
) -> Result(dict.Dict(String, String), String)

Extracts team and service name parameters from the file path.

pub fn parse_specification(
  file_path: String,
  params: dict.Dict(String, String),
  parse_fn: fn(glaml.Node, dict.Dict(String, String)) -> Result(
    a,
    String,
  ),
  key: String,
) -> Result(List(a), String)

Parses a specification file into a list of glaml documents according to the given parse function.

pub fn string_to_accepted_type(
  string_val: String,
) -> Result(accepted_types.AcceptedTypes, String)

Converts a string to an accepted type.

Search Document