caffeine_lang/types/ast
Types
A BasicType represents a fundamental data type with a name and type.
pub type BasicType {
BasicType(
attribute_name: String,
attribute_type: accepted_types.AcceptedTypes,
)
}
Constructors
-
BasicType( attribute_name: String, attribute_type: accepted_types.AcceptedTypes, )
A SliType is a named entity that represents the generic (as possible) definition of an SLI that references a query template.
pub type SliType {
SliType(
name: String,
query_template_type: QueryTemplateType,
typed_instatiation_of_query_templates: generic_dictionary.GenericDictionary,
specification_of_query_templatized_variables: List(BasicType),
)
}
Constructors
-
SliType( name: String, query_template_type: QueryTemplateType, typed_instatiation_of_query_templates: generic_dictionary.GenericDictionary, specification_of_query_templatized_variables: List(BasicType), )
An SLO is an expectation set by stakeholders upon a metric emulating the user experience as best as possible.
pub type Slo {
Slo(
typed_instatiation_of_query_templatized_variables: generic_dictionary.GenericDictionary,
threshold: Float,
sli_type: String,
service_name: String,
window_in_days: Int,
)
}
Constructors
-
Slo( typed_instatiation_of_query_templatized_variables: generic_dictionary.GenericDictionary, threshold: Float, sli_type: String, service_name: String, window_in_days: Int, )
A SpecificationOfMetrics is a list of expected metric filters by name and type.
pub type SpecificationOfMetrics =
List(BasicType)
A SpecificationOfQueryTemplates is a list of expected basic types by name and type.
pub type SpecificationOfQueryTemplates =
List(BasicType)
A TypedInstantiationOfMetrics is a dictionary of metric names to their typed instantiations.
pub type TypedInstantiationOfMetrics =
generic_dictionary.GenericDictionary
A TypedInstantiationOfQueryTemplates is a dictionary of query template names to their typed instantiations.
pub type TypedInstantiationOfQueryTemplates =
generic_dictionary.GenericDictionary