caffeine_lang/types/ast/specification_of_query_templates
Types
A SpecificationOfQueryTemplates is a list of expected basic types by name and type.
pub type SpecificationOfQueryTemplates =
List(basic_type.BasicType)
A SpecificationOfQueryTemplates is a list of expected basic types by name and type.
pub type SpecificationOfQueryTemplates =
List(basic_type.BasicType)