caffeine_lang/types/ast/typed_instantiation_of_metrics
Types
A TypedInstantiationOfMetrics is a dictionary of metric names to their typed instantiations.
pub type TypedInstantiationOfMetrics =
generic_dictionary.GenericDictionary
A TypedInstantiationOfMetrics is a dictionary of metric names to their typed instantiations.
pub type TypedInstantiationOfMetrics =
generic_dictionary.GenericDictionary