caffeine_query_language/resolver

Types

Supported primitive query types that can be resolved from CQL expressions. Each primitive represents a specific SLO calculation pattern.

pub type Primitives {
  GoodOverTotal(numerator: ast.Exp, denominator: ast.Exp)
  TimeSlice(
    comparator: ast.Comparator,
    interval_in_seconds: Int,
    threshold: Float,
    query: String,
  )
}

Constructors

  • GoodOverTotal(numerator: ast.Exp, denominator: ast.Exp)

    Good over total requires a top level division operator. Represents an SLO where the numerator is the “good” events and the denominator is the “total” events.

  • TimeSlice(
      comparator: ast.Comparator,
      interval_in_seconds: Int,
      threshold: Float,
      query: String,
    )
Search Document