caffeine_lang/common/modifier_types
Types
Modifier types are a special class of types that alter the value semantics of the attribute they are bound to.
pub type ModifierTypes(accepted) {
Optional(accepted)
Defaulted(accepted, String)
}
Constructors
-
Optional(accepted) -
Defaulted(accepted, String)Defaulted type stores the inner type and its default value as a string e.g., Defaulted(Integer, “10”) means an optional integer with default 10