caffeine_lang/frontend/parser
Values
pub fn parse_blueprints_file(
source: String,
) -> Result(
ast.BlueprintsFile(ast.Parsed),
List(parser_error.ParserError),
)
Parses a blueprints file from source text. Returns all recoverable parse errors rather than stopping at the first one.
pub fn parse_expects_file(
source: String,
) -> Result(
ast.ExpectsFile(ast.Parsed),
List(parser_error.ParserError),
)
Parses an expects file from source text. Returns all recoverable parse errors rather than stopping at the first one.