caffeine_lang/linker/artifacts
Types
Types of dependency relationships between expectations.
pub type DependencyRelationType {
Hard
Soft
}
Constructors
-
HardIf dependency down, dependent down.
-
SoftDependent can continue operating, either unscathed or within a degraded state if deendency down.
Information about a parameter including its type and description.
pub type ParamInfo {
ParamInfo(type_: types.AcceptedTypes, description: String)
}
Constructors
-
ParamInfo(type_: types.AcceptedTypes, description: String)