caffeine_lang/linker/artifacts

Types

A reusable artifact template with named parameters.

pub type Artifact {
  Artifact(
    type_: ArtifactType,
    description: String,
    params: dict.Dict(String, ParamInfo),
  )
}

Constructors

Types of supported artifacts.

pub type ArtifactType {
  SLO
  DependencyRelations
}

Constructors

  • SLO
  • DependencyRelations

Types of dependency relationships between expectations.

pub type DependencyRelationType {
  Hard
  Soft
}

Constructors

  • Hard

    If dependency down, dependent down.

  • Soft

    Dependent can continue operating, either unscathed or within a degraded state if deendency down.

Information about a parameter including its type and description.

pub type ParamInfo {
  ParamInfo(type_: types.AcceptedTypes, description: String)
}

Constructors

Search Document