caffeine_lang/linker/measurements
Types
A Measurement that references one or more Artifacts with parameters and inputs. It provides further params
for the Expectation to satisfy while providing a partial set of inputs for the Artifact’s params.
The phantom type parameter state tracks whether the measurement is Raw or MeasurementValidated.
pub type Measurement(state) {
Measurement(
name: String,
params: dict.Dict(String, types.AcceptedTypes),
inputs: dict.Dict(String, value.Value),
)
}
Constructors
-
Measurement( name: String, params: dict.Dict(String, types.AcceptedTypes), inputs: dict.Dict(String, value.Value), )
Marker type for measurements that have passed validation.
pub type MeasurementValidated