caffeine_lang/phase_2/linker/instantiation/linker
Values
pub fn aggregate_teams_and_slos(
teams: List(ast.Team),
) -> List(ast.Team)
Given a list of teams which map to single service SLOs, we want to aggregate all SLOs for a single team into a single team object.
pub fn link_and_validate_instantiation(
unresolved_team: instantiation_types.UnresolvedTeam,
services: List(ast.Service),
) -> Result(ast.Team, String)
pub fn resolve_filters(
unresolved_instantiated_filters: dict.Dict(String, String),
specification_filters: List(ast.BasicType),
) -> Result(generic_dictionary.GenericDictionary, String)
pub fn resolve_slo(
unresolved_slo: instantiation_types.UnresolvedSlo,
services: List(ast.Service),
) -> Result(ast.Slo, String)