pub fn aggregate_teams_and_slos( teams: List(ast.Team), ) -> List(ast.Team)
Given a list of teams which map to single service SLOs, we want to aggregate all SLOs for a single team into a single team object.