caffeine_lang/types/common/accepted_types
Types
AcceptedTypes is a union of all the types that can be used as filters. It is recursive to allow for nested filters. This may be a bug in the future since it seems it may infinitely recurse.
pub type AcceptedTypes {
Boolean
Decimal
Integer
String
NonEmptyList(AcceptedTypes)
Optional(AcceptedTypes)
}
Constructors
-
Boolean -
Decimal -
Integer -
String -
NonEmptyList(AcceptedTypes) -
Optional(AcceptedTypes)