caffeine_lang/value
Types
A typed value ADT that carries type information forward through the pipeline. Replaces the use of Dynamic for values in the compiler pipeline.
pub type Value {
StringValue(String)
IntValue(Int)
FloatValue(Float)
BoolValue(Bool)
ListValue(List(Value))
DictValue(dict.Dict(String, Value))
NilValue
}
Constructors
-
StringValue(String) -
IntValue(Int) -
FloatValue(Float) -
BoolValue(Bool) -
ListValue(List(Value)) -
-
NilValueRepresents an absent Optional or Defaulted value.